pub struct DynamicLinkStats {
pub link_event_stats: Option<Vec<DynamicLinkEventStat>>,
pub warnings: Option<Vec<DynamicLinkWarning>>,
}Expand description
Analytics stats of a Dynamic Link for a given timeframe.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get link stats (response)
Fields
link_event_stats: Option<Vec<DynamicLinkEventStat>>Dynamic Link event stats.
warnings: Option<Vec<DynamicLinkWarning>>Optional warnings associated this API request.