Struct google_firebasedynamiclinks1::api::SocialMetaTagInfo[][src]

pub struct SocialMetaTagInfo {
    pub social_description: Option<String>,
    pub social_image_link: Option<String>,
    pub social_title: Option<String>,
}

Parameters for social meta tag params. Used to set meta tag data for link previews on social sites.

This type is not used in any activity, and only used as part of another schema.

Fields

social_description: Option<String>

A short description of the link. Optional.

social_image_link: Option<String>

An image url string. Optional.

social_title: Option<String>

Title to be displayed. Optional.