pub struct CreateShortDynamicLinkResponse {
pub short_link: Option<String>,
pub warning: Option<Vec<DynamicLinkWarning>>,
pub preview_link: Option<String>,
}Expand description
Response to create a short Dynamic Link.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- create short links (response)
Fields
short_link: Option<String>Short Dynamic Link value. e.g. https://abcd.app.goo.gl/wxyz
warning: Option<Vec<DynamicLinkWarning>>Information about potential warnings on link creation.
preview_link: Option<String>Preivew link to show the link flow chart.