pub struct DynamicLinkInfo {
    pub navigation_info: Option<NavigationInfo>,
    pub analytics_info: Option<AnalyticsInfo>,
    pub link: Option<String>,
    pub ios_info: Option<IosInfo>,
    pub android_info: Option<AndroidInfo>,
    pub social_meta_tag_info: Option<SocialMetaTagInfo>,
    pub dynamic_link_domain: Option<String>,
}
Information about a Dynamic Link.

This type is not used in any activity, and only used as part of another schema.

Fields

navigation_info: Option<NavigationInfo>

Information of navigation behavior of a Firebase Dynamic Links.

analytics_info: Option<AnalyticsInfo>

Parameters used for tracking. See all tracking parameters in the documentation.

link: Option<String>

The link your app will open, You can specify any URL your app can handle. This link must be a well-formatted URL, be properly URL-encoded, and use the HTTP or HTTPS scheme. See ‘link’ parameters in the documentation.

Required.

ios_info: Option<IosInfo>

iOS related information. See iOS related parameters in the documentation.

android_info: Option<AndroidInfo>

Android related information. See Android related parameters in the documentation.

social_meta_tag_info: Option<SocialMetaTagInfo>

Parameters for social meta tag params. Used to set meta tag data for link previews on social sites.

dynamic_link_domain: Option<String>

Dynamic Links domain that the project owns, e.g. abcd.app.goo.gl Learn more on how to set up Dynamic Link domain associated with your Firebase project.

Required.