pub struct ITunesConnectAnalytics {
pub mt: Option<String>,
pub at: Option<String>,
pub pt: Option<String>,
pub ct: Option<String>,
}Expand description
Parameters for iTunes Connect App Analytics.
This type is not used in any activity, and only used as part of another schema.
Fields
mt: Option<String>iTune media types, including music, podcasts, audiobooks and so on.
at: Option<String>Affiliate token used to create affiliate-coded links.
pt: Option<String>Provider token that enables analytics for Dynamic Links from within iTunes Connect.
ct: Option<String>Campaign text that developers can optionally add to any link in order to track sales from a specific marketing campaign.