pub struct NavigationInfo {
pub enable_forced_redirect: Option<bool>,
}Expand description
Information of navigation behavior.
This type is not used in any activity, and only used as part of another schema.
Fields
enable_forced_redirect: Option<bool>If this option is on, FDL click will be forced to redirect rather than show an interstitial page.